import os
import uuid

from flask import Flask, flash, redirect, render_template, request, url_for
from flask_cors import CORS
from werkzeug.utils import secure_filename

from processing.process import process_all_files
from utils.constants import UPLOAD_FOLDER, debug, port

# Where the HTML templates are stored (yet frontend)
template_dir = os.path.abspath('templates')
# Initialize the Flask app
app = Flask("InfarctSize", template_folder=template_dir,
            static_url_path='', static_folder='static')
app.secret_key = uuid.uuid4().hex

# Allow CORS for the app (Cross-Origin Resource Sharing)
CORS(app)

# Load the web app


@app.route('/')
def home():
    return render_template('app.html')

# Test if the server is running


@app.route('/test')
def running():
    return "Server is running"

# Upload the images


@app.route('/upload', methods=['POST', 'GET'])
def upload():
    if request.method == 'GET':
        return redirect(url_for('home'))
    if request.method == 'POST':
        if 'image' not in request.files:
            flash('No file part')
            return redirect(request.url, code=400)

        files = request.files.getlist('image')
        for file in files:
            if file.filename == '':
                flash('No selected file')
                return redirect(request.url, code=400)
            filename = secure_filename(file.filename)
            file.save(os.path.join(UPLOAD_FOLDER, filename))
            print("File saved")

        return redirect(url_for('segment'))

# Process the uploaded images


@app.route('/segment', methods=['POST', 'GET'])
def segment():
    results = ''
    results = process_all_files()
    return results


if __name__ == '__main__':
    app.run(host='0.0.0.0', debug=debug, port=port)
