import segmentation_models_pytorch as smp
from torch import device, load
from torch.cuda import is_available as cuda_is_available

from models.unet_impl import UNet2
from utils.constants import (model_smp_deeplab, model_smp_unet,
                             model_unet_impl, num_classes)

device = device("cuda:0" if cuda_is_available() else "cpu")

# Load the models
net1 = UNet2(3, num_classes).to(device)
net1.load_state_dict(load(model_unet_impl, device))
net2 = smp.UnetPlusPlus(encoder_name='resnet34',
                        encoder_weights='imagenet', classes=num_classes).to(device)
net2.load_state_dict(load(model_smp_unet, device))
net3 = smp.DeepLabV3Plus(encoder_name='resnet34',
                         encoder_weights='imagenet', classes=num_classes).to(device)
net3.load_state_dict(load(model_smp_deeplab, device))

# Set the models to evaluation mode
net1.eval()
net2.eval()
net3.eval()
