import os
from concurrent.futures import ThreadPoolExecutor, as_completed

from processing.ainnotate import ainnotate
from utils.constants import UPLOAD_FOLDER


def process_files(files):
    results = {}
    try:
        with ThreadPoolExecutor() as executor:
            futures = [executor.submit(ainnotate, file, 50.0)
                       for file in files]
            for future in as_completed(futures):
                file, result = future.result()
                if result is not None:
                    results[file] = result
    except Exception as e:
        print(e)
        print("Error while processing files")
    return results


def process_all_files():
    files = os.listdir(UPLOAD_FOLDER)
    results = process_files(files)
    return results
