import copy

from torch import no_grad, save
from torch.optim import Adam

from train.utils import device

learning_rate = 0.006

def train(Net, DataLoader, optimizer,  criterion, AvgLoss):
    Net.train()
    IterNum = 0.0
    for batch_idx, (data_x, data_y) in enumerate(DataLoader):
        datax, datay = data_x.to(device), data_y.to(device)
        print(" No. of batch: " + str(batch_idx))
        datax = datax/127.5-1.0
        optimizer.zero_grad()
        response = Net(datax)
        loss = criterion(response, datay.float())
        loss.backward()
        AvgLoss += float(loss.item())
        IterNum += 1.0
        optimizer.step()
    AvgLoss = AvgLoss/IterNum
    return AvgLoss


def test(Net, test_loader,  criterion):
    Net.eval()
    AvgLoss = 0.0
    IterNum = 0.0
    with no_grad():
        for _, (data_x, data_y) in enumerate(test_loader):
            datax, datay = data_x.to(device), data_y.to(device)
            datax = datax/127.5-1.0
            response = Net(datax)

            loss = criterion(response, datay.float())
            AvgLoss += float(loss.item())
            IterNum += 1.0
    AvgLoss = AvgLoss/IterNum
    return AvgLoss


def train_for_epochs(Net, train_loader, test_loader, criterion, save_name, epoch_numb, best_loss):
    Net.train()
    optimizer = Adam(Net.parameters(), lr=learning_rate)
    best_weights = copy.deepcopy(Net.state_dict())
    save(Net.state_dict(), F"{save_name}")
    current_best_epoch = 0
    for epoch in range(epoch_numb):
        AvgLoss = 0.0
        print("Epoch: "+str(epoch))
        AvgLoss = train(Net, train_loader, optimizer, criterion, AvgLoss)
        TestLoss = test(Net, test_loader, criterion)
        print(" Avg Loss: " + str(AvgLoss))
        print(" Test Loss: " + str(TestLoss))
        if epoch == 0 and best_loss == 0:
            best_loss = TestLoss
        else:
            if TestLoss < best_loss:
                best_loss = TestLoss
                current_best_epoch = epoch
                print("Better parameters found...")
                best_weights = copy.deepcopy(Net.state_dict())
                save(Net.state_dict(), F"{save_name}")
                print("Parameters saved after epoch " + str(epoch) + ".")
        if epoch-9 > current_best_epoch:
            print("Loss hasn't improved in the last ten epochs, quitting...")
            print("Parameters saved last after epoch " +
                  str(current_best_epoch) + ".")
            break

    Net.load_state_dict(best_weights)
    return Net
