import random

import torchvision.transforms.functional as TF
from torch.cuda import is_available as cuda_is_available
from torch.utils.data import Dataset

device = 'cuda' if cuda_is_available() else 'cpu'

class MyDataset(Dataset):

    def __init__(self, imgs, masks):
        self.imgs = imgs
        self.masks = masks

    def __len__(self):
        return self.imgs.shape[0]

    def __getitem__(self, idx):
        image = self.imgs[idx]
        mask = self.masks[idx]

        image = TF.to_tensor(image)
        mask = TF.to_tensor(mask)

        if random.random() > 0.5:
            image = TF.hflip(image)
            mask = TF.hflip(mask)

        if random.random() > 0.5:
            image = TF.vflip(image)
            mask = TF.vflip(mask)

        return (image, mask)


class MyDataset_test(Dataset):

    def __init__(self, imgs, masks):
        self.imgs = imgs
        self.masks = masks

    def __len__(self):
        return self.imgs.shape[0]

    def __getitem__(self, idx):
        image = self.imgs[idx]
        mask = self.masks[idx]

        image = TF.to_tensor(image)
        mask = TF.to_tensor(mask)

        return (image, mask)
