
import cv2
import os
from utils.constants import UPLOAD_FOLDER
import numpy as np

# Method to calculate the score of the segmentation


def calculate_score(layer1, layer2, layer3, comb):
    if np.sum(comb >= 0.5) != 0:
        belongs_to_union = ((layer1 >= 0.5) | (
            layer2 >= 0.5)) | (layer3 >= 0.5)
        element_number = np.sum(belongs_to_union)
        probabilities = np.multiply(
            np.mean([layer1, layer2, layer3], axis=0), belongs_to_union)
        if element_number > 0:
            return np.sum(probabilities) / element_number
    return 0

# Method to reshape and threshold the mask


def reshape_and_threshold(mask):
    mask = np.transpose(mask, (3, 2, 1, 0))
    mask = np.where(mask < 0.0, 0.0, 1.0)
    mask = np.transpose(mask, (3, 0, 1, 2))
    return mask

# Method to convert RGBA to RGB


def cv2_RGBA2RGB(img, bg=(255, 255, 255)):
    b, g, r, a = cv2.split(img)
    alpha = a / 255
    r = (bg[0] * (1 - alpha) + r * alpha).astype(np.uint8)
    g = (bg[1] * (1 - alpha) + g * alpha).astype(np.uint8)
    b = (bg[2] * (1 - alpha) + b * alpha).astype(np.uint8)
    new_img = cv2.merge((b, g, r))
    return new_img


def delete_buff_image(file):
    try:
        os.remove(os.path.join(UPLOAD_FOLDER, file))
        print(f"{file} deleted")
    except Exception as e:
        print(f"Error while deleting file: {file}. Error message: {e}")
